==> drizzle_7.2.3.orig.tar.gz: drizzle-7.2.3/drizzled/util/tokenize.h <==
/* - mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
 *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 *
 *  Copyright (C) 2010 Monty Taylor
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#pragma once

namespace drizzled
{

template <class ContainerT>
void tokenize(const std::string& str, ContainerT& tokens, const std::string& delimiters= " ", bool trimEmpty= false)
{
  std::string::size_type pos;
  std::string::size_type lastPos= 0;

  while (true)
  {
    pos= str.find_first_of(delimiters, lastPos);
    if (pos == std::string::npos)
    {
      pos= str.length();

      if (pos != lastPos || not trimEmpty)
        tokens.push_back(typename ContainerT::value_type(str.data()+lastPos,
                                                         static_cast<typename ContainerT::value_type::size_type>(pos)-lastPos));

      break;
    }
    else
    {
      if (pos != lastPos || not trimEmpty)
        tokens.push_back(typename ContainerT::value_type(str.data()+lastPos,
                                                         static_cast<typename ContainerT::value_type::size_type>(pos)-lastPos));
    }

    lastPos= pos + 1;
  }
}

} /* namespace drizzled */

==> drizzle_2010.09.1802.orig.tar.gz: drizzle7-2010.09.1802/drizzled/util/tokenize.h <==
/* - mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
 *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 *
 *  Copyright (C) 2010 Monty Taylor
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef DRIZZLED_UTIL_TOKENIZE_H
#define DRIZZLED_UTIL_TOKENIZE_H

namespace drizzled
{

template <class ContainerT>
void tokenize(const std::string& str, ContainerT& tokens, const std::string& delimiters= " ", bool trimEmpty= false)
{
  std::string::size_type pos;
  std::string::size_type lastPos= 0;

  while (true)
  {
    pos= str.find_first_of(delimiters, lastPos);
    if (pos == std::string::npos)
    {
      pos= str.length();

      if (pos != lastPos || not trimEmpty)
        tokens.push_back(typename ContainerT::value_type(str.data()+lastPos,
                                                         static_cast<typename ContainerT::value_type::size_type>(pos)-lastPos));

      break;
    }
    else
    {
      if (pos != lastPos || not trimEmpty)
        tokens.push_back(typename ContainerT::value_type(str.data()+lastPos,
                                                         static_cast<typename ContainerT::value_type::size_type>(pos)-lastPos));
    }

    lastPos= pos + 1;
  }
}

} /* namespace drizzled */

#endif /* DRIZZLED_UTIL_TOKENIZE_H */
